@@ -5,6 +5,7 @@ import itertools
 import operator
 import os
 import re
+import sys
 
 from jinja2 import Environment, FileSystemLoader
 import sphinx
@@ -31,6 +32,14 @@ from ._objects import (
 )
 from .settings import OWN_PAGE_LEVELS, TEMPLATE_DIR
 
+if sys.version_info < (3, 10):  # PY310
+    from stdlib_list import in_stdlib
+else:
+
+    def in_stdlib(module_name: str) -> bool:
+        return module_name in sys.stdlib_module_names
+
+
 LOGGER = sphinx.util.logging.getLogger(__name__)
 
 
@@ -223,6 +232,22 @@ def _link_objs(value):
     return result[:-2]
 
 
+def _path_matches_patterns(path, patterns):
+    """Check if a path matches one of multiple patterns
+
+    Args:
+        path (str): path to a file or directory to check
+        patterns (list): list of patterns for fnmatch
+
+    Returns:
+        bool: Whether or not the path matches a pattern in patterns
+    """
+    for pattern in patterns:
+        if fnmatch.fnmatch(path, pattern):
+            return True
+    return False
+
+
 class Mapper:
     """Base class for mapping `PythonMapperBase` objects to Sphinx.
 
@@ -298,32 +323,37 @@ class Mapper:
             regex = re.compile(fnmatch.translate(pattern).replace(".*", "(.*)"))
             pattern_regexes.append((pattern, regex))
 
-        for _dir in dirs:
-            for root, _, filenames in os.walk(_dir):
+        for _dir in dirs:  # iterate autoapi_dirs
+            for root, subdirectories, filenames in os.walk(_dir):
+                # skip directories if needed
+                for sub_dir in subdirectories.copy():
+                    # iterate copy as we adapt subdirectories during loop
+                    if _path_matches_patterns(os.path.join(root, sub_dir), ignore):
+                        LOGGER.info(
+                            colorize("bold", "[AutoAPI] ")
+                            + colorize(
+                                "darkgreen", f"Ignoring directory: {root}/{sub_dir}/"
+                            )
+                        )
+                        # adapt original subdirectories inplace
+                        subdirectories.remove(sub_dir)
+                # recurse into remaining directories
                 seen = set()
                 for pattern, pattern_re in pattern_regexes:
                     for filename in fnmatch.filter(filenames, pattern):
-                        skip = False
-
                         match = re.match(pattern_re, filename)
                         norm_name = match.groups()
                         if norm_name in seen:
                             continue
 
                         # Skip ignored files
-                        for ignore_pattern in ignore:
-                            if fnmatch.fnmatch(
-                                os.path.join(root, filename), ignore_pattern
-                            ):
-                                LOGGER.info(
-                                    colorize("bold", "[AutoAPI] ")
-                                    + colorize(
-                                        "darkgreen", f"Ignoring {root}/{filename}"
-                                    )
+                        if _path_matches_patterns(os.path.join(root, filename), ignore):
+                            LOGGER.info(
+                                colorize("bold", "[AutoAPI] ")
+                                + colorize(
+                                    "darkgreen", f"Ignoring file: {root}/{filename}"
                                 )
-                                skip = True
-
-                        if skip:
+                            )
                             continue
 
                         # Make sure the path is full
@@ -385,7 +415,9 @@ class Mapper:
         if self.app.env.config_status != sphinx.environment.CONFIG_OK:
             return True
 
-        return last_files != files or not last_mtime or last_mtime < this_mtime
+        return (
+            set(last_files) != set(files) or not last_mtime or last_mtime < this_mtime
+        )
 
     def _find_files(self, patterns, dirs, ignore):
         for dir_ in dirs:
@@ -451,6 +483,24 @@ class Mapper:
             )
         return None
 
+    def _skip_if_stdlib(self):
+        documented_modules = {obj["full_name"] for obj in self.paths.values()}
+
+        q = collections.deque(self.paths.values())
+        while q:
+            obj = q.popleft()
+            if "children" in obj:
+                q.extend(obj["children"])
+
+            if obj.get("inherited", False):
+                module = obj["inherited_from"]["full_name"].split(".", 1)[0]
+                if (
+                    in_stdlib(module)
+                    and not obj["inherited_from"]["is_abstract"]
+                    and module not in documented_modules
+                ):
+                    obj["hide"] = True
+
     def _resolve_placeholders(self):
         """Resolve objects that have been imported from elsewhere."""
         modules = {}
@@ -477,6 +527,7 @@ class Mapper:
                         child["hide"] = True
 
     def map(self, options=None):
+        self._skip_if_stdlib()
         self._resolve_placeholders()
         self._hide_yo_kids()
         self.app.env.autoapi_annotations = {}
